<?php


// This theme supports native menu options, and uses wp_nav_menu() in one location for top navigation.
function fl_init() {
	global $cp_options;

	/* force disable style sheet */
	$cp_options->disable_stylesheet = 1;

	add_image_size( 'ad-thumb', 140, 110, true );
	add_image_size( 'ad-slider', 180, 120, true );
	add_image_size( 'ad-single', 530, 300, true );
	add_image_size( 'ad-single-large', 700, 400, true );

	register_nav_menus(array(
		'top' => __( 'Top Panel Navigation', APP_TD ),
	));

	remove_action( 'appthemes_after_blog_post_title', 'cp_blog_post_meta' );
	remove_action( 'appthemes_before_blog_post_title', 'cp_blog_comments_bubble' );
	remove_action( 'appthemes_after_post_content', 'cp_do_loop_stats' );
	remove_action( 'appthemes_after_blog_post_content', 'cp_do_loop_stats' );
	remove_action( 'appthemes_after_blog_post_content', 'cp_blog_post_meta_footer' );
	remove_action( 'appthemes_after_post_content', 'cp_blog_post_meta_footer' );
	remove_action( 'appthemes_after_post_content', 'cp_add_reset_stats_link' );
	remove_action( 'appthemes_after_blog_post_content', 'cp_add_reset_stats_link' );
	remove_action( 'appthemes_after_post_title', 'cp_ad_loop_meta' );
	remove_action( 'appthemes_after_post_content', 'cp_report_listing_button' );
	add_action( 'appthemes_after_post_content', 'cp_report_listing_button', 11 );

	/* comment actions removed */
	remove_action( 'appthemes_list_comments', 'cp_list_comments' );
	remove_action( 'appthemes_list_blog_comments', 'cp_list_comments' );
	remove_action( 'appthemes_list_page_comments', 'cp_list_comments' );
	remove_action( 'appthemes_list_pings', 'cp_list_pings' );
	remove_action( 'appthemes_list_blog_pings', 'cp_list_pings' );
	remove_action( 'appthemes_list_page_pings', 'cp_list_pings' );
	remove_action( 'appthemes_comments_form', 'cp_main_comment_form' );
	remove_action( 'appthemes_blog_comments_form', 'cp_main_comment_form' );
	remove_action( 'appthemes_page_comments_form', 'cp_main_comment_form' );

	remove_action( 'customize_register', '_cp_customize_color_scheme' );
	remove_action( 'customize_register', '_cp_customize_footer' );
	remove_action( 'wp_head', '_cp_customize_css', 999 );

	/* ACF compatibility */
	if( defined( 'ACF_VER' ) && version_compare( ACF_VER, '2.3', '>=' ) ) {
		remove_action( 'appthemes_after_post_title', 'acf_ad_loop_meta_top' );
	}

	if( is_admin() ) {
		if( function_exists('appthemes_add_instance' ) ) {
			appthemes_add_instance( array( 'FL_Theme_Settings_General' => $cp_options ) );
		} else {
			new FL_Theme_Settings_General( $cp_options );
		}
	}

}
add_action( 'init', 'fl_init' );

/**
 * Enqueue Font Awesome
 */
function fl_add_my_stylesheet() {

	global $cp_options;

	// Respects SSL, Style.css is relative to the current file
	wp_enqueue_style( 'font-awesome' );

	if( isset( $_GET['css'] ) ) {
		$css = $_GET['css'];
	} else {
		$css = fl_get_option( 'fl_stylesheet' );
	}

	wp_enqueue_style( 'fl-color', get_stylesheet_directory_uri() . '/css/' . $css . '.css', false );
	wp_dequeue_style( 'dashicons' );
}
add_action( 'wp_enqueue_scripts', 'fl_add_my_stylesheet', 100 );

function fl_add_google_fonts() {
	wp_enqueue_style( 'google-fonts', '//fonts.googleapis.com/css?family=Ubuntu:300,400,700,400italic' );
}
add_action( 'wp_enqueue_scripts', 'fl_add_google_fonts', 1 );

function fl_blog_post_meta() {
	// don't do post-meta on pages
	if ( is_page() ) {
		return;
	}

	global $post;
?>
	<div class="content-bar iconfix">
		<p class="meta">
			<span><i class="fa fa-user"></i><?php the_author_posts_link(); ?></span>
			<span><i class="fa fa-calendar"></i><?php echo appthemes_date_posted( $post->post_date ); ?></span>
			<span><i class="fa fa-folder-open"></i><?php the_category(', '); ?></span>
		</p>
		<p class="comment-count"><i class="fa fa-comments"></i><?php comments_popup_link( __( '0 Comments', APP_TD ), __( '1 Comment', APP_TD ), __( '% Comments', APP_TD ) ); ?></p>
	</div>
<?php
}
add_action( 'appthemes_after_blog_post_title', 'fl_blog_post_meta' );

function fl_ad_loop_meta() {
	global $post, $cp_options;
	if ( is_singular( APP_POST_TYPE ) ) {
		return;
	}
?>
	<div class="content-bar iconfix">
		<p class="meta">
			<span><i class="fa fa-user"></i><?php the_author_posts_link(); ?></span>
			<span><i class="fa fa-calendar"></i><?php echo appthemes_date_posted( $post->post_date ); ?></span>
			<span><i class="fa fa-folder-open"></i><?php if ( $post->post_type == 'post' ) the_category(', '); else echo get_the_term_list( $post->ID, APP_TAX_CAT, '', ', ', '' ); ?></span></span>
		</p>
	</div>
<?php
}
add_action( 'appthemes_after_post_title', 'fl_ad_loop_meta' );

function fl_do_loop_stats() {

	global $post, $cp_options;

	if ( is_singular( array( 'post', APP_POST_TYPE ) ) ) {
		return;
	}

	if ( ! $cp_options->ad_stats_all || ! current_theme_supports( 'app-stats' ) ) {
		return;
	}
?>
	<div class="content-bar text-footer iconfix">
		<?php if( get_post_type() == 'post' ) { ?>
			 <p class="tags"><i class="fa fa-tags"></i><?php if ( get_the_tags() ) echo the_tags( '', ', ', '' ); else _e( 'No Tags', APP_TD ); ?></p>
		<?php } ?>
		<p class="stats"><i class="fa fa-bar-chart"></i><?php appthemes_stats_counter( $post->ID ); ?></p>
	</div>
<?php
}
add_action( 'appthemes_after_post_content', 'fl_do_loop_stats' );
add_action( 'appthemes_after_blog_post_content', 'fl_do_loop_stats' );

function fl_blog_post_meta_footer() {
	global $post, $cp_options;
	if ( ! is_singular( array( 'post', APP_POST_TYPE ) ) )
		return;
?>
	<div class="content-bar text-footer iconfix">
	    <?php if ( is_singular( 'post' ) ) { ?>
        <p class="tags"><i class="fa fa-tags"></i><?php if ( get_the_tags() ) echo the_tags( '', ', ', '' ); else _e( 'No Tags', APP_TD ); ?></p>
        <?php } else { ?>
        <p class="tags"><i class="fa fa-tags"></i><?php if ( get_the_term_list( $post->ID, APP_TAX_TAG ) ) echo get_the_term_list( $post->ID, APP_TAX_TAG, '', ', ', '' ); else _e( 'No Tags', APP_TD ); ?></p>
        <?php } ?>
        <?php if ( $cp_options->ad_stats_all && current_theme_supports( 'app-stats' ) ) { ?><p class="stats"><i class="fa fa-bar-chart"></i><?php appthemes_stats_counter( $post->ID ); ?></p> <?php } ?>
    </div>
	<?php cp_edit_ad_link(); ?>
	<?php if( $cp_options->ad_stats_all ) {
		appthemes_reset_stats_link();
	} ?>
	<p class="edit"><?php if ( function_exists( 'wp_email' ) ) email_link(); ?>&nbsp;&nbsp;<?php if ( function_exists( 'wp_print' ) ) print_link(); ?></p>

<?php
}
add_action( 'appthemes_after_blog_post_content', 'fl_blog_post_meta_footer' );
add_action( 'appthemes_after_post_content', 'fl_blog_post_meta_footer', 11 );

function fl_featured_div() {
	if( is_sticky() ) { ?>
		<div class="featured-ad"></div>
	<?php }
}
add_action( 'appthemes_before_post_title', 'fl_featured_div' );

function fl_load_scripts() {
	global $cp_options;

	$params = array(
		'color_scheme' => $cp_options->fl_stylesheet,
		'colors'       => cp_get_customizer_color_defaults( 'all' ),
	);

	wp_localize_script( 'fl-themecustomizer', 'customizer_params', $params );

	wp_enqueue_script( 'fl-theme-scripts', get_stylesheet_directory_uri() . '/includes/js/theme-scripts.js', array( 'jquery' ) );
	wp_localize_script( 'fl-theme-scripts', 'flatpress_params', array( 'text_mobile_top_navigation' => fl_get_option( 'fl_lbl_top_navigation' ) ) );

}
add_action( 'wp_enqueue_scripts', 'fl_load_scripts', 100 );

function fl_body_class( $classes ) {

	if( fl_get_option( 'fl_layout_width' ) == 'extra' ) {
		$classes[] = 'extra-width';
	}

	if( fl_get_option( 'fl_mobile_navigation' ) == 'css' ) {
		$classes[] = 'responsive-menu';
	}

	return $classes;
}
add_filter( 'body_class', 'fl_body_class' );