<?php


global $cp_options, $fl_defaults;

class FL_Theme_Settings_General extends APP_Tabs_Page {

	function setup() {
		$this->textdomain = 'classipress';

		$this->args = array(
			'page_title' => __( 'FlatPress Settings', APP_TD ),
			'menu_title' => __( 'FlatPress Settings', APP_TD ),
			'page_slug' => 'flatpress',
			'parent' => 'app-dashboard',
			'screen_icon' => 'options-general',
			'admin_action_priority' => 100,
		);

	}

	protected function init_tabs() {
		
		$colors = fl_get_color_choices();

		$this->tabs->add( 'general', __( 'General', APP_TD ) );
		
		$this->tab_sections['general']['styling'] = array(
			'title' => __( 'Styling', APP_TD ),
			'fields' => array(
				array(
					'title' => __( 'Current Colour Scheme', APP_TD ),
					'desc' => sprintf( __( 'Customize the look and feel of your website by visiting the <a href="%s">WordPress customizer</a>.' , APP_TD ), 'customize.php?return=' . esc_url( admin_url( 'admin.php?page=flatpress' ) ) ),
					'type' => 'text',
					'name' => 'fl_blank',
					'value' => $colors[fl_get_option( 'fl_stylesheet' )],
					'extra' => array(
						'disabled' => 'disabled',
						'readonly' => 'readonly',
						'style' => 'font-weight:bold;',
					),
					'tip' => '',
				),
				array(
					'title' => __( 'Layout Width', APP_TD ),
					'type' => 'select',
					'name' => 'fl_layout_width',
					'desc' => '',
					'tip' => __( 'Select layout width. Use 1140px for extra wide layout.', APP_TD ),
					'value' => fl_get_option( 'fl_layout_width' ),
					'values' => array(
						'normal' => '960px (Default)',
						'extra' => '1140px',
					),
				),
			),
		);
		
		$this->tab_sections['general']['mobile_navigation'] = array(
			'title' => __( 'Mobile Navigation', APP_TD ),
			'fields' => array(
				array(
					'title' => __( 'Primary Navigation Type', APP_TD ),
					'type' => 'select',
					'name' => 'fl_mobile_navigation',
					'desc' => '',
					'tip' => __( 'Select the type of primary navigation for smaller screen mobile widths.', APP_TD ),
					'value' => fl_get_option( 'fl_mobile_navigation' ),
					'values' => array(
						'select' => 'HTML Select Box (Default)',
						'css' => 'Responsive CSS',
					),
				),
				array(
					'title' => __( 'Top Panel Navigation Label', APP_TD ),
					'type' => 'text',
					'name' => 'fl_lbl_top_navigation',
					'desc' => '',
					'tip' => __( 'Select the label for top panel navigation for smaller screen mobile widths.', APP_TD ),
					'value' => fl_get_option( 'fl_lbl_top_navigation' ),
				),
			),
		);
		
		$this->tab_sections['general']['single_ad'] = array(
			'title' => __( 'Single Ad Pages', APP_TD ),
			'fields' => array(
				array(
					'title' => __( 'Ad Details Title', APP_TD ),
					'type' => 'text',
					'name' => 'fl_single_ad_details_title',
					'desc' => '',
					'tip' => __( 'Title for ad details section just below images on single ad page.', APP_TD ),
					'value' => fl_get_option( 'fl_single_ad_details_title' ),
				),
				array(
					'title' => __( 'Hide Image Place Holder', APP_TD ),
					'type' => 'checkbox',
					'name' => 'fl_hide_single_ad_placeholder',
					'desc' => '',
					'tip' => __( 'Check to hide the empty image place holder on single ad pages.', APP_TD ),
				),
			),
		);
		
		$this->tab_sections['general']['button_labels'] = array(
			'title' => __( 'Button Labels', APP_TD ),
			'fields' => array(
				array(
					'title' => __( 'Learn More', APP_TD ),
					'type' => 'text',
					'name' => 'fl_lbl_learn_more',
					'desc' => __( 'Appears on the slider', APP_TD ),
					'tip' => __( 'Keep it short.', APP_TD ),
					'value' => fl_get_option( 'fl_lbl_learn_more' ),
				),
			),
		);
		
		$this->tab_sections['general']['instructions'] = array(
			'title' => __( 'Instructions', APP_TD ),
			'description' => html( 'p', __('If you were using the default ClassiPress theme or another child theme before, your image thumbnails may need to be updated for optimum usage with the FlatPress theme. Please install the <a href="http://wordpress.org/plugins/ajax-thumbnail-rebuild/" target="_blank">AJAX Thumbnail Rebuild</a> plugin and rebuild all your thumbnails just once for this purpose.', APP_TD) )
			. html( 'p', __('Read the installation guide <a href="https://themebound.com/shop/flatpress-responsive-child-theme-classipress/" target="_blank">here</a>. Enjoy the theme and please report any issue you encounter to <a href="mailto:info@themebound.com">info@themebound.com</a>. Follow us on <a href="https://twitter.com/#!/themebound" target="_blank">Twitter</a>, and like us on <a href="https://www.facebook.com/themebound" target="_blank">Facebook</a> to get updates on new products and useful tips.', APP_TD) ),
			'renderer' => array( $this, 'render_instructions' ),
			'fields' => array(),
		);

	}
	
	function form_handler() {
		if ( empty( $_POST['action'] ) || ! $this->tabs->contains( $_POST['action'] ) )
			return;

		check_admin_referer( $this->nonce );

		$form_fields = array();

		foreach ( $this->tab_sections[ $_POST['action'] ] as $section ) {
			$form_fields = array_merge( $form_fields, $section['fields'] );
		}

		$to_update = scbForms::validate_post_data( $form_fields, null, $this->options->get() );
		unset( $to_update['fl_blank'] );

		$this->options->update( $to_update, false );

		do_action( 'tabs_' . $this->pagehook . '_form_handler', $this );
		add_action( 'admin_notices', array( $this, 'admin_msg' ) );
	}
	
	function render_instructions( $section, $section_id ) {
		if( $section_id == 'instructions' ) {
			echo $section['description'];
		}
	}

}

function fl_admin_notices() {
	$fl_name = wp_get_theme()->get( 'Name' );
	$fl_version = wp_get_theme()->get( 'Version' );
	$fl_parent = wp_get_theme()->parent()->get( 'Name' );
	$fl_parent_version = wp_get_theme()->parent()->get( 'Version' );
	
	if( version_compare( $fl_parent_version, FL_PARENT_MIN, '>=' ) ) {
		return;
	}
	
	$request_link = ( sprintf( 'mailto:info@themebound.com?subject=Request for a %1$s version compatible with %2$s %3$s&body=My AppThemes username is: APPTHEMES_USERNAME (replace with your correct username).', $fl_name, $fl_parent, $fl_parent_version ) );

	$msg = sprintf( __( '<strong>%1$s %2$s</strong> <em>requires at least</em> <strong>%3$s %5$s</strong> to function properly, please either upgrade %3$s or <a href="%6$s">request</a> a version of %1$s that is compatible with %3$s %4$s.', APP_TD ), $fl_name, $fl_version, $fl_parent, $fl_parent_version, FL_PARENT_MIN, $request_link );

	echo scb_admin_notice( $msg, 'notice notice-error' );
}
add_action( 'admin_notices', 'fl_admin_notices' );