<?php
/**
 * Updates the color pickers using javascript each time the user changes the theme color scheme.
 */
function fl_enqueue_customizer_color_previewer() {
	global $cp_options;

	wp_dequeue_script( 'cp_themecustomizer' );

	wp_enqueue_script( 'fl-themecustomizer', get_stylesheet_directory_uri() . '/includes/js/theme-customizer.js', array( 'customize-controls' ), CP_VERSION, true );

	$params = array(
		'color_scheme' => $cp_options->fl_stylesheet,
		'colors'       => cp_get_customizer_color_defaults( 'all' ),
	);

	wp_localize_script( 'fl-themecustomizer', 'customizer_params', $params );
}
add_action( 'customize_controls_enqueue_scripts', 'fl_enqueue_customizer_color_previewer', 11 );

function fl_edit_customizer( $wp_customize ) {
	$wp_customize->remove_control( 'cp_search_field_width' );
	$wp_customize->remove_setting( 'cp_options[search_field_width]' );

	$wp_customize->remove_control( 'cp_display_website_time' );
	$wp_customize->remove_setting( 'cp_options[display_website_time]' );
}
add_action( 'customize_register', 'fl_edit_customizer', 11 );

/**
 * Displays the theme color choices in the customizer.
 */
function fl_customize_color_scheme( $wp_customize ){
	global $cp_options;

	$color_defaults = cp_get_customizer_color_defaults();

	$wp_customize->add_setting( 'cp_options[fl_stylesheet]', array(
		'default' => $cp_options->fl_stylesheet,
		'type'    => 'option',
	) );

	$wp_customize->add_control( 'cp_color_scheme', array(
		'label'      => __( 'Color Scheme', APP_TD ),
		'section'    => 'colors',
		'settings'   => 'cp_options[fl_stylesheet]',
		'type'       => 'radio',
		'choices'	 => fl_get_color_choices(),
		'priority'	 => 1,
	) );

	$wp_customize->add_setting( 'cp_options[bgcolor]', array(
		'default' => $cp_options->bgcolor,
		'type'    => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_bgcolor',
			array(
				'label'		=> __( 'Main Background Color', APP_TD ),
				'section'	=> 'colors',
				'settings'	=> 'cp_options[bgcolor]',
				'priority'	=> 1,
			)
		)
	);

	$wp_customize->add_setting( 'cp_options[top_nav_bgcolor]', array(
		'default' => $cp_options->cp_top_nav_bgcolor,
		'type'    => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_top_nav_bgcolor',
			array(
				'label'		=> __( 'Top Navigation Bar Color', APP_TD ),
				'section'	=> 'colors',
				'settings'	=> 'cp_options[top_nav_bgcolor]',
				'priority'	=> 2,
			)
		)
	);

	$wp_customize->add_setting( 'cp_options[top_nav_links_color]', array(
		'default' => $cp_options->cp_top_nav_links_color,
		'type' => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_top_nav_links_color',
			array(
				'label'		=> __( 'Top Navigation Links Color', APP_TD ),
				'section'	=> 'colors',
				'settings'	=> 'cp_options[top_nav_links_color]',
				'priority'	=> 3,
			)
		)
	);

	$wp_customize->add_setting( 'cp_options[top_nav_text_color]', array(
		'default' => $cp_options->cp_top_nav_text_color,
		'type' => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_top_nav_text_color',
			array(
				'label'		=> __( 'Top Navigation Text Color', APP_TD ),
				'section'	=> 'colors',
				'settings'	=> 'cp_options[top_nav_text_color]',
				'priority'	=> 4,
			)
		)
	);

	$wp_customize->add_setting( 'cp_options[header_bgcolor]', array(
		'default' => $cp_options->header_bgcolor,
		'type'    => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_header_bgcolor',
			array(
				'label'		=> __( 'Header Background Color', APP_TD ),
				'section'	=> 'colors',
				'settings'	=> 'cp_options[header_bgcolor]',
				'priority'	=> 9,
			)
		)
	);

	$wp_customize->add_setting( 'cp_options[main_nav_bgcolor]', array(
		'default' => $cp_options->cp_main_nav_bgcolor,
		'type'    => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_main_nav_bgcolor',
			array(
				'label'		=> __( 'Secondary Color (Darker than Header)', APP_TD ),
				'description'	=> __( 'Applies to main navigation bar, breadcrumbs and labels on refine search and contact forms.', APP_TD ),
				'section'	=> 'colors',
				'settings'	=> 'cp_options[main_nav_bgcolor]',
				'priority'	=> 12,
			)
		)
	);

	$wp_customize->add_setting( 'cp_options[buttons_bgcolor]', array(
		'default' => $cp_options->cp_buttons_bgcolor,
		'type'    => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_buttons_bgcolor',
			array(
				'label'		=> __( 'Buttons Color', APP_TD ),
				'section'	=> 'colors',
				'settings'	=> 'cp_options[buttons_bgcolor]',
				'priority'	=> 13,
			)
		)
	);

	$wp_customize->add_setting( 'cp_options[contrast_color]', array(
		'default' => $cp_options->cp_contrast_color,
		'type'    => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_contrast_color',
			array(
				'label'		=> __( 'Contrast Color', APP_TD ),
				'description'	=> __( 'Applies to post ad button and refine sliders.', APP_TD ),
				'section'	=> 'colors',
				'settings'	=> 'cp_options[contrast_color]',
				'priority'	=> 15,
			)
		)
	);

	$wp_customize->add_setting( 'cp_options[price_color]', array(
		'default' => $cp_options->cp_price_color,
		'type'    => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_price_color',
			array(
				'label'		=> __( 'Price Color', APP_TD ),
				'description'	=> __( 'Applies to price labels.', APP_TD ),
				'section'	=> 'colors',
				'settings'	=> 'cp_options[price_color]',
				'priority'	=> 15,
			)
		)
	);

	$wp_customize->add_setting( 'cp_options[links_color]', array(
		'default' => $cp_options->cp_links_color,
		'type' => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_links_color',
			array(
				'label'		  => __( 'Links Color', APP_TD ),
				'section'	  => 'colors',
				'settings'	  => 'cp_options[links_color]',
				'priority'	  => 15,
			)
		)
	);

	$wp_customize->add_setting( 'cp_options[footer_bgcolor]', array(
		'default' => $cp_options->footer_bgcolor,
		'type'    => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_footer_bgcolor',
			array(
				'label'		=> __( 'Footer Background Color', APP_TD ),
				'section'	=> 'colors',
				'settings'	=> 'cp_options[footer_bgcolor]',
				'priority'	=> 16,
			)
		)
	);

	$wp_customize->add_setting( 'cp_options[footer_text_color]', array(
		'default' => $cp_options->cp_footer_text_color,
		'type' => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_footer_text_color',
			array(
				'label'		=> __( 'Footer Text Color', APP_TD ),
				'section'	=> 'colors',
				'settings'	=> 'cp_options[footer_text_color]',
				'priority'	=> 17,
			)
		)
	);

	$wp_customize->add_setting( 'cp_options[footer_titles_color]', array(
		'default' => $color_defaults['cp_footer_titles_color'],
		'type' => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_footer_titles_color',
			array(
				'label'		=> __( 'Footer Titles Color', APP_TD ),
				'section'	=> 'colors',
				'settings'	=> 'cp_options[footer_titles_color]',
				'priority'	=> 18,
			)
		)
	);

	$wp_customize->add_setting( 'cp_options[footer_links_color]', array(
		'default' => $color_defaults['cp_footer_links_color'],
		'type' => 'option'
	) );

	$wp_customize->add_control(
		new WP_Customize_Color_Control(	$wp_customize,
			'cp_footer_links_color',
			array(
				'label'		=> __( 'Footer Links Color', APP_TD ),
				'section'	=> 'colors',
				'settings'	=> 'cp_options[footer_links_color]',
				'priority'	=> 19,
			)
		)
	);

}
add_action( 'customize_register', 'fl_customize_color_scheme' );

function fl_customizer_color_defaults( $defaults ) {
	return array(
		'style-default.css' => array(
			//page
			'cp_bgcolor'				=> '',
			// top nav
			'cp_top_nav_bgcolor'         => '',
			'cp_top_nav_links_color'     => '',
			'cp_top_nav_text_color'      => '',
			// header
			'cp_header_bgcolor'          => '',
			// main nav
			'cp_main_nav_bgcolor'        => '',
			'cp_main_nav_links_color'    => '',
			// other
			'cp_links_color'			 => '',
			'cp_buttons_bgcolor'         => '',
			'cp_contrast_color'			 => '',
			'cp_price_color'			 => '',
			// footer
			'cp_footer_bgcolor'          => '',
			'cp_footer_text_color'       => '',
			'cp_footer_links_color'      => '',
			'cp_footer_titles_color'     => '',
		),
		'blue' => array(
			//page
			'cp_bgcolor'				=> '#f5f5f5',
			// top nav
			'cp_top_nav_bgcolor'         => '#323232',
			'cp_top_nav_links_color'     => '#999',
			'cp_top_nav_text_color'      => '#fff',
			// header
			'cp_header_bgcolor'          => '#2daacd',
			// main nav
			'cp_main_nav_bgcolor'        => '#1b83a0',
			'cp_main_nav_links_color'    => '#fff',
			// other
			'cp_links_color'			 => '#19aacf',
			'cp_buttons_bgcolor'         => '#19aacf',
			'cp_contrast_color'			 => '#f45435',
			'cp_price_color'			 => '#6abe59',
			// footer
			'cp_footer_bgcolor'          => '#fff',
			'cp_footer_text_color'       => '#555655',
			'cp_footer_links_color'      => '#19aacf',
			'cp_footer_titles_color'     => '#555655',
		),
		'green' => array(
			//page
			'cp_bgcolor'				=> '#f5f5f5',
			// top nav
			'cp_top_nav_bgcolor'         => '#323232',
			'cp_top_nav_links_color'     => '#999',
			'cp_top_nav_text_color'      => '#fff',
			// header
			'cp_header_bgcolor'          => '#6abe59',
			// main nav
			'cp_main_nav_bgcolor'        => '#4ca837',
			'cp_main_nav_links_color'    => '#fff',
			// other
			'cp_links_color'			 => '#6abe59',
			'cp_buttons_bgcolor'         => '#6abe59',
			'cp_contrast_color'			 => '#f45435',
			'cp_price_color'			 => '#f45435',
			// footer
			'cp_footer_bgcolor'          => '#fff',
			'cp_footer_text_color'       => '#555655',
			'cp_footer_links_color'      => '#6abe59',
			'cp_footer_titles_color'     => '#555655',
		),
		'red' => array(
			//page
			'cp_bgcolor'				=> '#f5f5f5',
			// top nav
			'cp_top_nav_bgcolor'         => '#323232',
			'cp_top_nav_links_color'     => '#999',
			'cp_top_nav_text_color'      => '#fff',
			// header
			'cp_header_bgcolor'          => '#D84136',
			// main nav
			'cp_main_nav_bgcolor'        => '#C0392B',
			'cp_main_nav_links_color'    => '#fff',
			// other
			'cp_links_color'			 => '#D84136',
			'cp_buttons_bgcolor'         => '#D84136',			
			'cp_contrast_color'			 => '#FC6D26',			
			'cp_price_color'			 => '#6abe59',
			// footer
			'cp_footer_bgcolor'          => '#fff',
			'cp_footer_text_color'       => '#555655',
			'cp_footer_links_color'      => '#D84136',
			'cp_footer_titles_color'     => '#555655',
		),
		'golden' => array(
			//page
			'cp_bgcolor'				=> '#f5f5f5',
			// top nav
			'cp_top_nav_bgcolor'         => '#323232',
			'cp_top_nav_links_color'     => '#999',
			'cp_top_nav_text_color'      => '#fff',
			// header
			'cp_header_bgcolor'          => '#F39C12',
			// main nav
			'cp_main_nav_bgcolor'        => '#E67E22',
			'cp_main_nav_links_color'    => '#fff',
			// other
			'cp_links_color'			 => '#F39C12',
			'cp_buttons_bgcolor'         => '#F39C12',			
			'cp_contrast_color'			 => '#D84136',			
			'cp_price_color'			 => '#6abe59',
			// footer
			'cp_footer_bgcolor'          => '#fff',
			'cp_footer_text_color'       => '#555655',
			'cp_footer_links_color'      => '#F39C12',
			'cp_footer_titles_color'     => '#555655',
		),
		'dark-blue' => array(
			//page
			'cp_bgcolor'				=> '#f5f5f5',
			// top nav
			'cp_top_nav_bgcolor'         => '#323232',
			'cp_top_nav_links_color'     => '#999',
			'cp_top_nav_text_color'      => '#fff',
			// header
			'cp_header_bgcolor'          => '#34495E',
			// main nav
			'cp_main_nav_bgcolor'        => '#2C3E50',
			'cp_main_nav_links_color'    => '#fff',
			// other
			'cp_links_color'			 => '#34495E',
			'cp_buttons_bgcolor'         => '#34495E',			
			'cp_contrast_color'			 => '#D84136',			
			'cp_price_color'			 => '#6abe59',
			// footer
			'cp_footer_bgcolor'          => '#fff',
			'cp_footer_text_color'       => '#555655',
			'cp_footer_links_color'      => '#34495E',
			'cp_footer_titles_color'     => '#555655',
		),
		'purple' => array(
			//page
			'cp_bgcolor'				=> '#f5f5f5',
			// top nav
			'cp_top_nav_bgcolor'         => '#323232',
			'cp_top_nav_links_color'     => '#999',
			'cp_top_nav_text_color'      => '#fff',
			// header
			'cp_header_bgcolor'          => '#9B59B6',
			// main nav
			'cp_main_nav_bgcolor'        => '#8E44AD',
			'cp_main_nav_links_color'    => '#fff',
			// other
			'cp_links_color'			 => '#9B59B6',
			'cp_buttons_bgcolor'         => '#9B59B6',			
			'cp_contrast_color'			 => '#D84136',			
			'cp_price_color'			 => '#6abe59',
			// footer
			'cp_footer_bgcolor'          => '#fff',
			'cp_footer_text_color'       => '#555655',
			'cp_footer_links_color'      => '#9B59B6',
			'cp_footer_titles_color'     => '#555655',
		),
		'grey' => array(
			//page
			'cp_bgcolor'				=> '#f5f5f5',
			// top nav
			'cp_top_nav_bgcolor'         => '#323232',
			'cp_top_nav_links_color'     => '#999',
			'cp_top_nav_text_color'      => '#fff',
			// header
			'cp_header_bgcolor'          => '#95A5A6',
			// main nav
			'cp_main_nav_bgcolor'        => '#7f8c8d',
			'cp_main_nav_links_color'    => '#fff',
			// other
			'cp_links_color'			 => '#95A5A6',
			'cp_buttons_bgcolor'         => '#95A5A6',			
			'cp_contrast_color'			 => '#D84136',			
			'cp_price_color'			 => '#6abe59',
			// footer
			'cp_footer_bgcolor'          => '#fff',
			'cp_footer_text_color'       => '#555655',
			'cp_footer_links_color'      => '#95A5A6',
			'cp_footer_titles_color'     => '#555655',
		),
		'bronze' => array(
			//page
			'cp_bgcolor'				=> '#f5f5f5',
			// top nav
			'cp_top_nav_bgcolor'         => '#323232',
			'cp_top_nav_links_color'     => '#999',
			'cp_top_nav_text_color'      => '#fff',
			// header
			'cp_header_bgcolor'          => '#E2691D',
			// main nav
			'cp_main_nav_bgcolor'        => '#D35400',
			'cp_main_nav_links_color'    => '#fff',
			// other
			'cp_links_color'			 => '#E2691D',
			'cp_buttons_bgcolor'         => '#E2691D',			
			'cp_contrast_color'			 => '#FC6D26',			
			'cp_price_color'			 => '#6abe59',
			// footer
			'cp_footer_bgcolor'          => '#fff',
			'cp_footer_text_color'       => '#555655',
			'cp_footer_links_color'      => '#E2691D',
			'cp_footer_titles_color'     => '#555655',
		),
		'brown' => array(
			//page
			'cp_bgcolor'				=> '#f5f5f5',
			// top nav
			'cp_top_nav_bgcolor'         => '#323232',
			'cp_top_nav_links_color'     => '#999',
			'cp_top_nav_text_color'      => '#fff',
			// header
			'cp_header_bgcolor'          => '#B27130',
			// main nav
			'cp_main_nav_bgcolor'        => '#8b5f30',
			'cp_main_nav_links_color'    => '#fff',
			// other
			'cp_links_color'			 => '#B27130',
			'cp_buttons_bgcolor'         => '#B27130',			
			'cp_contrast_color'			 => '#FC6D26',			
			'cp_price_color'			 => '#6abe59',
			// footer
			'cp_footer_bgcolor'          => '#fff',
			'cp_footer_text_color'       => '#555655',
			'cp_footer_links_color'      => '#B27130',
			'cp_footer_titles_color'     => '#555655',
		),
		'turquoise' => array(
			//page
			'cp_bgcolor'				=> '#f5f5f5',
			// top nav
			'cp_top_nav_bgcolor'         => '#323232',
			'cp_top_nav_links_color'     => '#999',
			'cp_top_nav_text_color'      => '#fff',
			// header
			'cp_header_bgcolor'          => '#1ABC9C',
			// main nav
			'cp_main_nav_bgcolor'        => '#16A085',
			'cp_main_nav_links_color'    => '#fff',
			// other
			'cp_links_color'			 => '#1ABC9C',
			'cp_buttons_bgcolor'         => '#1ABC9C',			
			'cp_contrast_color'			 => '#FC6D26',			
			'cp_price_color'			 => '#F45435',
			// footer
			'cp_footer_bgcolor'          => '#fff',
			'cp_footer_text_color'       => '#555655',
			'cp_footer_links_color'      => '#1ABC9C',
			'cp_footer_titles_color'     => '#555655',
		),
		'charcoal' => array(
			//page
			'cp_bgcolor'				=> '#f5f5f5',
			// top nav
			'cp_top_nav_bgcolor'         => '#323232',
			'cp_top_nav_links_color'     => '#999',
			'cp_top_nav_text_color'      => '#fff',
			// header
			'cp_header_bgcolor'          => '#666666',
			// main nav
			'cp_main_nav_bgcolor'        => '#555555',
			'cp_main_nav_links_color'    => '#fff',
			// other
			'cp_links_color'			 => '#666666',
			'cp_buttons_bgcolor'         => '#666666',			
			'cp_contrast_color'			 => '#FC6D26',			
			'cp_price_color'			 => '#6abe59',
			// footer
			'cp_footer_bgcolor'          => '#fff',
			'cp_footer_text_color'       => '#555655',
			'cp_footer_links_color'      => '#666666',
			'cp_footer_titles_color'     => '#555655',
		),
	);
}
add_filter( 'cp_customizer_color_defaults', 'fl_customizer_color_defaults' );

/**
 * Overrides the theme styles with the Customizer options.
 */
function fl_customize_css() {
	global $cp_options;
?>

    <style type="text/css">

		<?php if ( $cp_options->bgcolor ) : ?>
			.content_botbg, #search-bar { background-color: <?php echo $cp_options->bgcolor; ?>; }
		<?php endif; ?>

		<?php if ( $cp_options->links_color ) : ?>
			a, .post-block .post-right h3 a, .content_right ul li a, .header_top_res ul.menu ul.sub-menu li a:hover, div#adv_categories .catcol ul li.maincat > a { color: <?php echo $cp_options->links_color; ?>; }
		<?php endif; ?>

		<?php if ( $cp_options->top_nav_bgcolor ) : ?>
			.header_top { background: <?php echo $cp_options->top_nav_bgcolor; ?>;  }
		<?php endif; ?>

		<?php if ( $cp_options->top_nav_links_color ) : ?>
			.header_top_res a, .header_top_res li:after, .header_top_res .add-nav li:last-child::after { color: <?php echo $cp_options->top_nav_links_color; ?>; }
		<?php endif; ?>

		<?php if ( $cp_options->top_nav_text_color ) : ?>
			.header_top_res { color: <?php echo $cp_options->top_nav_text_color; ?>;  }
		<?php endif; ?>

		<?php if ( $cp_options->header_bgcolor ) : ?>
			.header_main, .header_menu_res ul li.current-menu-parent > a, .header_menu_res ul li.current-menu-item > a, .header_menu_res a.menu-toggle, .footer .bar { background-color: <?php echo $cp_options->header_bgcolor; ?>; }
			.footer { border-color: <?php echo $cp_options->header_bgcolor; ?>; }
			@media screen and (max-width: 800px) {
				.header_menu_res ul.menu li a { background-color: <?php echo $cp_options->header_bgcolor; ?>; }
			}
		<?php endif; ?>

		<?php if ( $cp_options->main_nav_bgcolor ) : ?>
			.header_menu { background: <?php echo $cp_options->main_nav_bgcolor; ?>; }
			ol.progtrckr li.progtrckr-done:before { background-color: <?php echo $cp_options->main_nav_bgcolor; ?>; }
			ol.progtrckr li.progtrckr-done { border-color: <?php echo $cp_options->main_nav_bgcolor; ?>; }
			.bigright ul li span, #breadcrumb a, ul.refine label.title, .form_contact label:not(.invalid) { color: <?php echo $cp_options->main_nav_bgcolor; ?>; }
		<?php endif; ?>

		<?php if ( $cp_options->buttons_bgcolor ) : ?>
			.btn-topsearch, .button, .btn_orange, .content_right .btn_orange, .order-gateway input[type="submit"], .reports_form input[type="submit"], .tabcontrol ul.tabnavig li a, .tabprice ul.tabnavig li a, .comment-reply-link, #app-attachment-upload-pickfiles, #app-attachment-upload-filelist .app-attachment .button, .home .paging > a, form.filter input.submit, .paging .pages span.current { background-color: <?php echo $cp_options->buttons_bgcolor; ?>; }
			#block1, #block2, #block3, #priceblock1, #priceblock2, #priceblock3 { border-color: <?php echo $cp_options->buttons_bgcolor; ?>; }
		<?php endif; ?>

		<?php if ( $cp_options->contrast_color ) : ?>
			ul.refine li input#amount, ul.refine li input#distance { color:<?php echo $cp_options->contrast_color; ?>; }
			.header_menu_res .obtn, ul.refine .ui-slider-horizontal .ui-slider-range, ul.refine .ui-slider-horizontal .ui-slider-handle { background-color:<?php echo $cp_options->contrast_color; ?>; }
		<?php endif; ?>

		<?php if ( $cp_options->price_color ) : ?>
			span.price_sm { color:<?php echo $cp_options->price_color; ?>; }
			p.post-price { background-color:<?php echo $cp_options->price_color; ?>; }
		<?php endif; ?>

		<?php if ( $cp_options->footer_bgcolor ) : ?>
			.footer { background: <?php echo $cp_options->footer_bgcolor; ?>; }
		<?php endif; ?>

		<?php if ( $cp_options->footer_text_color ) : ?>
			.footer_main_res div.column { color: <?php echo $cp_options->footer_text_color; ?>; }
		<?php endif; ?>

		<?php if ( $cp_options->footer_titles_color ) : ?>
			.footer_main_res div.column h1, .footer_main_res div.column h2, .footer_main_res div.column h3 { color: <?php echo $cp_options->footer_titles_color; ?>; }
		<?php endif; ?>

		<?php if ( $cp_options->footer_links_color ) : ?>
			.footer_main_res div.column a, .footer_main_res div.column ul li a { color: <?php echo $cp_options->footer_links_color; ?>; }
		<?php endif; ?>

	</style>
<?php
}
add_action( 'wp_head', 'fl_customize_css', 999 );